==> magpie-data-0.1.5-sources.jar: io/openraven/magpie/data/aws/redshift/RedshiftCluster.java <==
/*-
 * #%L
 * Magpie API
 * %%
 * Copyright (C) 2021 Open Raven Inc
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * #L%
 */
/*
 * Copyright 2021 Open Raven Inc
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.openraven.magpie.data.aws.redshift;

import io.openraven.magpie.data.aws.AWSResource;
import io.openraven.magpie.data.aws.shared.PayloadUtils;
import software.amazon.awssdk.services.redshift.model.Cluster;

@javax.persistence.Entity
@javax.persistence.Inheritance(strategy = javax.persistence.InheritanceType.TABLE_PER_CLASS)
@javax.persistence.Table(name = RedshiftCluster.TABLE_NAME)
public class RedshiftCluster extends AWSResource {

  protected static final String TABLE_NAME = "awsredshiftcluster";
  public static final String RESOURCE_TYPE = "AWS::Redshift::Cluster";

  @SuppressWarnings("unused")
  public RedshiftCluster() {
    this.resourceType = RESOURCE_TYPE;
  }

  public RedshiftCluster(String regionId, Cluster cluster, String accountId) {
    this.awsRegion = regionId;
    this.resourceType = RESOURCE_TYPE;
    this.resourceId = cluster.clusterIdentifier();
    this.arn = String.format("arn:aws:redshift:%s:%s:cluster:%s", regionId, accountId, cluster.clusterIdentifier());
    this.resourceName = cluster.dbName();
    this.configuration = PayloadUtils.update(cluster);
    this.awsAccountId = accountId;
    this.createdIso = cluster.clusterCreateTime();
  }
}

==> magpie-data-0.11.6-sources.jar: io/openraven/magpie/data/aws/redshift/RedshiftCluster.java <==
/*-
 * #%L
 * Magpie API
 * %%
 * Copyright (C) 2021 Open Raven Inc
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * #L%
 */
/*
 * Copyright 2021 Open Raven Inc
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.openraven.magpie.data.aws.redshift;

import io.openraven.magpie.data.aws.AWSResource;
import io.openraven.magpie.data.aws.shared.PayloadUtils;
import software.amazon.awssdk.services.redshift.model.Cluster;

@jakarta.persistence.Entity
@jakarta.persistence.Inheritance(strategy = jakarta.persistence.InheritanceType.TABLE_PER_CLASS)
@jakarta.persistence.Table(name = RedshiftCluster.TABLE_NAME)
public class RedshiftCluster extends AWSResource {

  protected static final String TABLE_NAME = "awsredshiftcluster";
  public static final String RESOURCE_TYPE = "AWS::Redshift::Cluster";

  @SuppressWarnings("unused")
  public RedshiftCluster() {
    this.resourceType = RESOURCE_TYPE;
  }

  public RedshiftCluster(String regionId, Cluster cluster, String accountId) {
    this.awsRegion = regionId;
    this.resourceType = RESOURCE_TYPE;
    this.resourceId = cluster.clusterIdentifier();
    this.arn = String.format("arn:aws:redshift:%s:%s:cluster:%s", regionId, accountId, cluster.clusterIdentifier());
    this.resourceName = cluster.dbName();
    this.configuration = PayloadUtils.update(cluster);
    this.awsAccountId = accountId;
    this.createdIso = cluster.clusterCreateTime();
  }
}
